@@ -1,17 +1,20 @@
-import json
 import allure
-import boto3
 import pandas as pd
 import time, os
 import logging
-import s3fs
-from toolkit_w.internal.api_requestor import APIRequestor
-from toolkit_w.internal.token_json import UserToken
-from toolkit_w.internal.vars_global import ProblemType, TargetMetric, FeatureType
-from toolkit_w.internal.vars_global import InterpretabilityLevel as Interpt
-import toolkit_w as my_toolkit
+# from toolkit_w.internal.api_requestor import APIRequestor
+# from toolkit_w.internal.token_json import UserToken
+# from toolkit_w.internal.vars_global import ProblemType, TargetMetric, FeatureType
+# from toolkit_w.internal.vars_global import InterpretabilityLevel as Interpt
+# import toolkit_w as my_toolkit
+import fireflyai as my_toolkit
 from ast import literal_eval
 
+import fireflyai
+from fireflyai.token_json import UserToken
+from fireflyai.api_requestor import APIRequestor
+from fireflyai.enums import FeatureType, ProblemType, TargetMetric, InterpretabilityLevel as Interpt
+
 logging.getLogger().setLevel(logging.INFO)
 logging.basicConfig(level=logging.INFO, format='%(levelname)s:%(message)s')
 
@@ -327,9 +330,9 @@ class MyWhatify:
             pipeline = cls.get_pipeline_estimators_list(dataset_id, True, interpt_level)
             estimators = cls.get_pipeline_estimators_list(dataset_id, False, interpt_level)
             if interpt_level == Interpt.EXPLAINABLE:
-                interpretability_level = my_toolkit.vars_global.InterpretabilityLevel.EXPLAINABLE
+                interpretability_level = my_toolkit.enums.InterpretabilityLevel.EXPLAINABLE
             else:
-                interpretability_level = my_toolkit.vars_global.InterpretabilityLevel.PRECISE
+                interpretability_level = my_toolkit.enums.InterpretabilityLevel.PRECISE
 
             # print('The training time is:', Training_time_in_minutes)
             # print ('The selected Target Metric is:', Target_metric.value)
